<?php

namespace Teknisa\TCO\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource;

class Tco01500FornecedorPrioritarioProduto extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    protected $environment;
    protected $entityManager;

    public function __construct($crudService, $parameterBag, $environment, $entityManager) {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
    }
    
    public function salvaProdutoFornecedor(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $row["__is_new_code"] = true;
        $row["__new_code_pk"] = "FORNEPRIOTCO";
        $row["__table_pk"] = "NRFORNEPRIOTCO";
        $row["__new_code_length"] = 1;
        $row["NRORG"] = $this->environment->getNrOrgTrab();
        
        $produtoEncontrado = $this->produtoSelecionadoExistente($row);
        
        if(!$produtoEncontrado) {
            $this->salvaNovoProdutoFornecedor(array($row));
            $response->addDataSet(new DataSet("fornepriotco", array()));
        } else {
            $validacoes = array(
                "message" => "TCO01500_PRODUTO_EM_USO",
                "params" => $produtoEncontrado
            );
            $response->addDataSet(new DataSet("validacoes", $validacoes));
        }
        
    }
    
    private function produtoSelecionadoExistente($row) {
        
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT FORNEPRIOTCO.NRFORNEPRIOTCO,
                       FORNEPRIOTCO.CDREGIAO,
                       FORNEPRIOTCO.CDPRODUTO,
                       PRODUTO.NMPRODUTO,
                       FORNEPRIOTCO.CDFORNECED,
                       FORNECEDOR.NRINSJURFORN,
                       FORNECEDOR.IDTPIJURFORN,
                       FORNECEDOR.NMRAZSOCFORN,
                       FORNECEDOR.NMFANTFORN,
                       FORNEPRIOTCO.NRORG
                  FROM FORNEPRIOTCO
                 INNER JOIN PRODUTO
                    ON PRODUTO.CDPRODUTO = FORNEPRIOTCO.CDPRODUTO
                 INNER JOIN FORNECEDOR
                    ON FORNECEDOR.CDFORNECED = FORNEPRIOTCO.CDFORNECED
                 WHERE FORNEPRIOTCO.CDPRODUTO = :CDPRODUTO
                   AND FORNEPRIOTCO.CDREGIAO = :CDREGIAO
                   AND FORNEPRIOTCO.NRORG = :NRORG
                 ORDER BY PRODUTO.CDARVPROD ASC";
        
        $query = $connection->prepare($sql);
        
        $params = array(
            "CDPRODUTO"  => $row["CDPRODUTO"],
            "CDREGIAO"  => $row["CDREGIAO"],
            "NRORG"      => $row["NRORG"]
        ); 
        
        $query->execute($params);
        
        $result = $query->fetch(\PDO::FETCH_ASSOC);
        
        return $result;
        
    }
    
    private function salvaNovoProdutoFornecedor($row) {
        $newdataSet = new DataSet("fornepriotco", $row);
        $newrequest = new DTO\Request\DataSet($newdataSet, "", "", "");
        $rows = $this->crudService->getRowsToSave($newrequest, "fornepriotco");
        $this->crudService->save("fornepriotco", $rows);
    }
    
    public function excluiProdutosFornecedor(DTO\Request $request, DTO\Response $response) {
        $this->excluiProdutos($request, $response);
    }
    
    private function excluiProdutos($request, $response) {
        $rows = $this->crudService->getRowsToDelete($request, 'fornepriotco');
        $dataSet = new DataSet("fornepriotco", $rows);
		$this->crudService->delete($response, $dataSet);
    }

}
